@@ -45,6 +45,11 @@ renv_path_normalize_win32 <- function(path,
                                       winslash = "/",
                                       mustWork = FALSE)
 {
+
+  # see the NOTE above, this workaround is only necessary for R < 4 and it complicates things unnecessarily
+  if (getRversion() >= "4.0.0")
+    return(normalizePath(path, winslash, mustWork))
+
   # get encoding for this set of paths
   enc <- Encoding(path)
 
@@ -89,5 +94,5 @@ renv_path_component <- function(path, index = 1) {
 }
 
 renv_path_pretty <- function(path) {
-  shQuote(aliased_path(path), type = "cmd")
+  renv_json_quote(aliased_path(path))
 }
