@@ -1,6 +1,7 @@
 box::use(
+    .,
     A,
     b = B,
     C[...],
-    D[c, d]
+    D[c, d],
 )
